package com.totopia.server.init;

import java.util.HashSet;
import java.util.stream.Collectors;
import java.util.stream.Stream;

import com.totopia.server.modules.dashboard.repository.DashboardRepository;
import com.totopia.server.modules.user.entity.RoleEntity;
import com.totopia.server.modules.user.entity.UserEntity;
import com.totopia.server.modules.user.repository.RoleRepository;
import com.totopia.server.modules.user.repository.UserRepository;
import com.totopia.server.modules.user.type.RoleName;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.CommandLineRunner;
import org.springframework.boot.autoconfigure.condition.ConditionalOnProperty;
import org.springframework.security.crypto.password.PasswordEncoder;
import org.springframework.stereotype.Component;

@Component
@ConditionalOnProperty(name = "app.db-init", havingValue = "true")
public class DbInitializer implements CommandLineRunner {

  @Autowired
  private RoleRepository roleRepository;

  @Autowired
  private UserRepository userRepository;

  @Autowired
  PasswordEncoder passwordEncoder;

  @Autowired
  DashboardRepository dashboardRepository;

  @Override
  public void run(String... strings) throws Exception {
    if (0 == roleRepository.count()) {
      RoleEntity role = null;
      role = RoleEntity.builder().name(RoleName.ROLE_ADMIN).build();
      roleRepository.save(role);
      role = RoleEntity.builder().name(RoleName.ROLE_USER).build();
      roleRepository.save(role);
    }

    if (0 == userRepository.count()) {
      UserEntity user = null;
      user = UserEntity.builder().username("admin").password(passwordEncoder.encode("admin")).nickname("admin")
          .email("admin@example.com").roles(Stream.of(RoleEntity.builder().id(Short.valueOf((short) 1)).build())
              .collect(Collectors.toCollection(HashSet::new)))
          .build();

      userRepository.save(user);
    }

    System.out.println(" -- Database has been initialized");
  }
}
